==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+47"/>
        <source>Status Bar Font:</source>
        <translation>Шрифт строки статуса</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Виджеты строки статуса</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Дисплей координаты</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Дисплей мыши</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Дисплей выделения</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Дисплей прогресса</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Виджеты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Строка статуса</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>&amp;Панель состояния</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+53"/>
        <source>Status Bar Font:</source>
        <translation>Шрифт строки статуса</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Виджеты строки статуса</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Дисплей координаты</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Дисплей мыши</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Дисплей выделения</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Дисплей прогресса</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Show status tips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Виджеты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Строка статуса</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>&amp;Панель состояния</translation>
    </message>
</context>
</TS>
